Module: ActiveModel::Validations
- Defined in:
- lib/validatious/helper_methods.rb
Defined Under Namespace
Modules: HelperMethods
Constant Summary collapse
- UrlValidator =
Compatibility with ActiveModel validates method which matches option keys to their validator class
Validatious::Validators::UrlValidator
- EmailValidator =
Compatibility with ActiveModel validates method which matches option keys to their validator class
Validatious::Validators::EmailValidator
- PostalCodeValidator =
Compatibility with ActiveModel validates method which matches option keys to their validator class
Validatious::Validators::PostalCodeValidator
- TextContentValidator =
Compatibility with ActiveModel validates method which matches option keys to their validator class
Validatious::Validators::TextContentValidator